@@ -11,8 +11,6 @@ import yaml
 import psycopg2
 import click
 from pathlib import Path
-from fdsnextender import FdsnExtender
-from resifdatareporter import __version__
 logging.basicConfig(format='%(asctime)s %(levelname)s: %(message)s', level=logging.INFO)
 logger = logging.getLogger(__name__)
 
@@ -44,11 +42,15 @@ def scan_volume(path):
                 logger.info("%s is probably not a normal path. Skip it.", path)
                 continue
             if re.match('[1-9][0-9]{3}', path[0]):
+                is_permanent = not re.match('^[1-9XYZ]', path[0])
                 data.append({'year': path[0], 'network': path[1], 'station': path[2],
-                             'channel': channel, 'quality': quality, 'size': size})
+                             'channel': channel, 'quality': quality, 'size': size,
+                             'is_permanent': is_permanent })
             else:
+                is_permanent = not re.match('^[1-9XYZ]', path[1])
                 data.append({'year': path[1], 'network': path[0], 'station': path[2],
-                             'channel': channel, 'quality': quality, 'size': size})
+                             'channel': channel, 'quality': quality, 'size': size,
+                             'is_permanent': is_permanent })
             logger.debug(data[-1])
     logger.debug("Volume scanned in %s", datetime.now() - starttime)
     return data
@@ -122,7 +124,6 @@ def scan_volumes(volumes):
 @click.option('--force-scan', flag_value=True, default=False, help='Force scanning of the archive')
 @click.option('--dryrun', flag_value=True, default=False, help="Do not send metrics to database")
 @click.option("--verbose", flag_value=True, default=False, help="Verbose mode")
-@click.version_option(__version__)
 def cli(configfile, force_scan, dryrun, verbose, version):
     """
     Command line interface. Stands as main
@@ -160,24 +161,6 @@ def cli(configfile, force_scan, dryrun, verbose, version):
 
     statistics = scan_volumes(cfg['volumes'])
 
-    # add the network_type (is the network permanent or not) to the statistic
-    # also insert the extended network code.
-    extender = FdsnExtender()
-    for stat in statistics:
-        # Les réseaux commençant par 1 à 9 et X Y Z sont des réseaux non
-        # permanents
-        stat['is_permanent'] = not re.match('^[1-9XYZ]', stat['network'])
-        # Si le réseau temporaire est en 2 lettres, alors on veut son nom
-        # étendu
-        if not stat['is_permanent'] and len(stat['network']) < 3 :
-            try:
-                stat['network'] = extender.extend(
-                    stat['network'], int(stat['year']))
-            except ValueError:
-                logger.debug("Network %s exists ?" % stat['network'])
-        stat['date'] = today
-        logger.debug(stat)
-
     if dryrun:
         logger.info("Dryrun mode, dump stats and exit")
         for stat in statistics:
@@ -187,7 +170,7 @@ def cli(configfile, force_scan, dryrun, verbose, version):
     if 'postgres' in cfg:
         logger.info('Writing to postgres database')
         conn = psycopg2.connect(dbname=cfg['postgres']['database'], user=cfg['postgres']['user'],
-                                host=cfg['postgres']['host'], password=cfg['postgres']['password'], port=cfg['postgres']['port'])
+                                host=cfg['postgres']['host'], port=cfg['postgres']['port'])
         cur = conn.cursor()
         for stat in statistics:
             try:
@@ -197,7 +180,7 @@ def cli(configfile, force_scan, dryrun, verbose, version):
                     VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
                     ON CONFLICT (network,year,station,channel,type,date) DO UPDATE SET size = EXCLUDED.size;
                     """,
-                    (stat['network'], stat['year'], stat['station'], stat['channel'], stat['quality'], stat['type'], stat['size'], stat['is_permanent'], stat['volume'], stat['date']))
+                    (stat['network'], stat['year'], stat['station'], stat['channel'], stat['quality'], stat['type'], stat['size'], stat['is_permanent'], stat['volume'], today))
             except psycopg2.Error as err:
                 logging.error(err)
                 logging.info(cur.mogrify(
@@ -206,7 +189,7 @@ def cli(configfile, force_scan, dryrun, verbose, version):
                     VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
                     ON CONFLICT (network,year,station,channel,type,date) DO UPDATE SET size = EXCLUDED.size;
                     """,
-                    (stat['network'], stat['year'], stat['station'], stat['channel'], stat['quality'], stat['type'], stat['size'], stat['is_permanent'], stat['volume'], stat['date'])
+                    (stat['network'], stat['year'], stat['station'], stat['channel'], stat['quality'], stat['type'], stat['size'], stat['is_permanent'], stat['volume'], today)
                 ))
         conn.commit()
 
